==> jettable1.0.0.zip: jettable/client.php <==
<?php
require_once "TableUtility.php";

$list = array();
for($i = 0; $i < 10; $i++){
	$list[] = array("ID"=>"000001","ܵ̾"=>"",""=>"Թݣݣ","TEL"=>"03-1111-1111","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000002","ܵ̾"=>"ƹ",""=>"Թݣݣ","TEL"=>"03-1111-2222","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000003","ܵ̾"=>"Ұ",""=>"Թݣݣ","TEL"=>"03-1111-3333","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000004","ܵ̾"=>"ʩ",""=>"Թݣݣ","TEL"=>"03-1111-4444","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000005","ܵ̾"=>"Ұ",""=>"Թݣݣ","TEL"=>"03-1111-5555","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000006","ܵ̾"=>"ұѵ",""=>"Թݣݣ","TEL"=>"03-1111-6666","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000007","ܵ̾"=>"",""=>"Թݣݣ","TEL"=>"03-1111-7777","̾"=>"̳",""=>"");
	$list[] = array("ID"=>"000008","ܵ̾"=>"Ϫ",""=>"Թݣݣ","TEL"=>"03-1111-8888","̾"=>"̳");
	$list[] = array("ID"=>"000009","ܵ̾"=>"ī",""=>"Թݣݣ","TEL"=>"03-1111-9999","̾"=>"");
	$list[] = array("ID"=>"000010","ܵ̾"=>"Ҵڹ",""=>"Թݣݣ","TEL"=>"03-1111-1122");
	$list[] = array("ID"=>"000011","ܵ̾"=>"ҿ",""=>"Թݣݣ","TEL"=>"03-1111-2233",""=>"");
	$list[] = array("ID"=>"000012","ܵ̾"=>"ҿŵ",""=>"Թݣݣ","TEL"=>"03-1111-2244","̾"=>"PC",""=>"");
	$list[] = array("ID"=>"000013","ܵ̾"=>"ҹ",""=>"Թݣݣ","TEL"=>"03-1111-4455","̾"=>"PC",""=>"");
	$list[] = array("ID"=>"000014","ܵ̾"=>"",""=>"Թݣݣ","TEL"=>"03-1111-6677","̾"=>"PC",""=>"");
	$list[] = array("ID"=>"000015","ܵ̾"=>"Ұ",""=>"Թݣݣ","TEL"=>"03-1111-8899","̾"=>"PC",""=>"");
}
$table = new Table();
$table->setData($list);
$table->fullstackInitialize($_REQUEST);

$table->appendAttribute("border", "1");
$table->appendAttributeHeaderRow("style", "background-color:#cfc;");


print "<hr>";
print $table->getFullStackTableHtml();

print "<hr>";
$pager = $table->getPagerHtml();
print $pager;
print "<pre>";
print $table->getTableText();
print "</pre>";
print $pager;
?>

==> jettable2.0.0.zip: jettable/client.php <==
<?php
require_once "JetTable.php";

$list = array();
for($i = 0; $i < 10; $i++){
	$list[] = array("ID"=>"000001","ܵ̾"=>"",""=>"Թݣݣ","TEL"=>"03-1111-1111","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000002","ܵ̾"=>"ƹ",""=>"Թݣݣ","TEL"=>"03-1111-2222","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000003","ܵ̾"=>"Ұ",""=>"Թݣݣ","TEL"=>"03-1111-3333","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000004","ܵ̾"=>"ʩ",""=>"Թݣݣ","TEL"=>"03-1111-4444","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000005","ܵ̾"=>"Ұ",""=>"Թݣݣ","TEL"=>"03-1111-5555","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000006","ܵ̾"=>"ұѵ",""=>"Թݣݣ","TEL"=>"03-1111-6666","̾"=>"ʸ˼",""=>"");
	$list[] = array("ID"=>"000007","ܵ̾"=>"",""=>"Թݣݣ","TEL"=>"03-1111-7777","̾"=>"̳",""=>"");
	$list[] = array("ID"=>"000008","ܵ̾"=>"Ϫ",""=>"Թݣݣ","TEL"=>"03-1111-8888","̾"=>"̳");
	$list[] = array("ID"=>"000009","ܵ̾"=>"ī",""=>"Թݣݣ","TEL"=>"03-1111-9999","̾"=>"");
	$list[] = array("ID"=>"000010","ܵ̾"=>"Ҵڹ",""=>"Թݣݣ","TEL"=>"03-1111-1122");
	$list[] = array("ID"=>"000011","ܵ̾"=>"ҿ",""=>"Թݣݣ","TEL"=>"03-1111-2233",""=>"");
	$list[] = array("ID"=>"000012","ܵ̾"=>"ҿŵ",""=>"Թݣݣ","TEL"=>"03-1111-2244","̾"=>"PC",""=>"");
	$list[] = array("ID"=>"000013","ܵ̾"=>"ҹ",""=>"Թݣݣ","TEL"=>"03-1111-4455","̾"=>"PC",""=>"");
	$list[] = array("ID"=>"000014","ܵ̾"=>"",""=>"Թݣݣ","TEL"=>"03-1111-6677","̾"=>"PC",""=>"");
	$list[] = array("ID"=>"000015","ܵ̾"=>"Ұ",""=>"Թݣݣ","TEL"=>"03-1111-8899","̾"=>"PC",""=>"");
}
$table = new JetTable();
$table->setData($list);
$table->fullstackInitialize($_REQUEST);

$table->appendAttribute("border", "1");
$table->appendAttributeHeaderRow("style", "background-color:#cfc;");


print "<hr>";
print $table->getFullStackTableHtml();

print "<hr>";
$pager = $table->getPagerHtml();
print $pager;
print "<pre>";
print $table->getTableText();
print "</pre>";
print $pager;
?>
